module.exports = defineTest({
	description: 'does bind export as default (#1078)'
});
